@@ -1,16 +1,24 @@
 from pollination_dsl.dag import Inputs, DAG, task, Outputs
 from dataclasses import dataclass
 from pollination.honeybee_radiance.sun import CreateSunMatrix, ParseSunUpHours
-from pollination.honeybee_radiance.translate import CreateRadianceFolder
+from pollination.honeybee_radiance.translate import CreateRadianceFolderGrid
 from pollination.honeybee_radiance.octree import CreateOctree, CreateOctreeWithSky
 from pollination.honeybee_radiance.sky import CreateSkyDome, CreateSkyMatrix
+from pollination.honeybee_radiance.post_process import AnnualDaylightMetrics
 
 
 # input/output alias
 from pollination.alias.inputs.model import hbjson_model_input
 from pollination.alias.inputs.wea import wea_input
 from pollination.alias.inputs.north import north_input
-from pollination.alias.outputs.daylight import sort_annual_daylight_results
+from pollination.alias.inputs.radiancepar import rad_par_annual_input, \
+    daylight_thresholds_input
+from pollination.alias.inputs.grid import sensor_count_input, grid_filter_input
+from pollination.alias.inputs.schedule import schedule_csv_input
+from pollination.alias.outputs.daylight import annual_daylight_results, \
+    daylight_autonomy_results, continuous_daylight_autonomy_results, \
+    udi_results, udi_lower_results, udi_upper_results
+
 
 from ._raytracing import AnnualDaylightRayTracing
 
@@ -30,17 +38,23 @@ class AnnualDaylightEntryPoint(DAG):
     sensor_count = Inputs.int(
         default=200,
         description='The maximum number of grid points per parallel execution.',
-        spec={'type': 'integer', 'minimum': 1}
+        spec={'type': 'integer', 'minimum': 1},
+        alias=sensor_count_input
     )
 
     radiance_parameters = Inputs.str(
         description='The radiance parameters for ray tracing.',
-        default='-ab 2 -ad 5000 -lw 2e-05'
+        default='-ab 2 -ad 5000 -lw 2e-05',
+        alias=rad_par_annual_input
     )
 
-    sensor_grid = Inputs.str(
-        description='A grid name or a pattern to filter the sensor grids. By default '
-        'all the grids in HBJSON model will be exported.', default='*'
+    grid_filter = Inputs.str(
+        description='Text for a grid identifer or a pattern to filter the sensor grids '
+        'of the model that are simulated. For instance, first_floor_* will simulate '
+        'only the sensor grids that have an identifier that starts with '
+        'first_floor_. By default, all grids in the model will be simulated.',
+        default='*',
+        alias=grid_filter_input
     )
 
     model = Inputs.file(
@@ -55,6 +69,23 @@ class AnnualDaylightEntryPoint(DAG):
         alias=wea_input
     )
 
+    schedule = Inputs.file(
+        description='Path to an annual schedule file. Values should be 0-1 separated '
+        'by new line. If not provided an 8-5 annual schedule will be created.',
+        extensions=['txt', 'csv'], optional=True, alias=schedule_csv_input
+    )
+
+    thresholds = Inputs.str(
+        description='A string to change the threshold for daylight autonomy and useful '
+        'daylight illuminance. Valid keys are -t for daylight autonomy threshold, -lt '
+        'for the lower threshold for useful daylight illuminance and -ut for the upper '
+        'threshold. The default is -t 300 -lt 100 -ut 3000. The order of the keys is not '
+        'important and you can include one or all of them. For instance if you only '
+        'want to change the upper threshold to 2000 lux you should use -ut 2000 as '
+        'the input.', default='-t 300 -lt 100 -ut 3000',
+        alias=daylight_thresholds_input
+    )
+
     @task(template=CreateSunMatrix)
     def generate_sunpath(self, north=north, wea=wea):
         """Create sunpath for sun-up-hours."""
@@ -66,17 +97,17 @@ class AnnualDaylightEntryPoint(DAG):
             }
         ]
 
-    @task(template=CreateRadianceFolder)
-    def create_rad_folder(self, input_model=model, sensor_grid=sensor_grid):
+    @task(template=CreateRadianceFolderGrid)
+    def create_rad_folder(self, input_model=model, grid_filter=grid_filter):
         """Translate the input model to a radiance folder."""
         return [
-            {'from': CreateRadianceFolder()._outputs.model_folder, 'to': 'model'},
+            {'from': CreateRadianceFolderGrid()._outputs.model_folder, 'to': 'model'},
             {
-                'from': CreateRadianceFolder()._outputs.sensor_grids_file,
+                'from': CreateRadianceFolderGrid()._outputs.sensor_grids_file,
                 'to': 'results/grids_info.json'
             },
             {
-                'from': CreateRadianceFolder()._outputs.sensor_grids,
+                'from': CreateRadianceFolderGrid()._outputs.sensor_grids,
                 'description': 'Sensor grids information.'
             }
         ]
@@ -165,7 +196,52 @@ class AnnualDaylightEntryPoint(DAG):
     ):
         pass
 
+    @task(
+        template=AnnualDaylightMetrics,
+        needs=[parse_sun_up_hours, annual_daylight_raytracing]
+    )
+    def calculate_annual_metrics(
+        self, folder='results', schedule=schedule, thresholds=thresholds
+    ):
+        return [
+            {
+                'from': AnnualDaylightMetrics()._outputs.annual_metrics,
+                'to': 'metrics'
+            }
+        ]
+
     results = Outputs.folder(
-        source='results',
-        alias=sort_annual_daylight_results
+        source='results', description='Folder with raw result files (.ill) that '
+        'contain illuminance matrices.', alias=annual_daylight_results
+    )
+
+    metrics = Outputs.folder(
+        source='metrics', description='Annual metrics folder.'
+    )
+
+    da = Outputs.folder(
+        source='metrics/da', description='Daylight autonomy results.',
+        alias=daylight_autonomy_results
+    )
+
+    cda = Outputs.folder(
+        source='metrics/cda', description='Continuous daylight autonomy results.',
+        alias=continuous_daylight_autonomy_results
+    )
+
+    udi = Outputs.folder(
+        source='metrics/udi', description='Useful daylight illuminance results.',
+        alias=udi_results
+    )
+
+    udi_lower = Outputs.folder(
+        source='metrics/udi_lower', description='Results for the percent of time that '
+        'is below the lower threshold of useful daylight illuminance.',
+        alias=udi_lower_results
+    )
+
+    udi_upper = Outputs.folder(
+        source='metrics/udi_upper', description='Results for the percent of time that '
+        'is above the upper threshold of useful daylight illuminance.',
+        alias=udi_upper_results
     )
